@@ -29,7 +29,9 @@ __all__ = (
     "TableStatusType",
     "ThroughputModeType",
     "TimeToLiveStatusType",
+    "KeyspacesServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -51,6 +53,7 @@ TableStatusType = Literal[
 ]
 ThroughputModeType = Literal["PAY_PER_REQUEST", "PROVISIONED"]
 TimeToLiveStatusType = Literal["ENABLED"]
+KeyspacesServiceName = Literal["keyspaces"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -353,4 +356,16 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_keyspaces", "list_tables", "list_tags_for_resource"]
